.. _combinatorics-util:

Utilities
============

.. module:: sympy.combinatorics.util

.. autofunction:: _base_ordering

.. autofunction:: _check_cycles_alt_sym

.. autofunction:: _distribute_gens_by_base

.. autofunction:: _handle_precomputed_bsgs

.. autofunction:: _orbits_transversals_from_bsgs

.. autofunction:: _remove_gens

.. autofunction:: _strip

.. autofunction:: _strong_gens_from_distr
